@@ -72,7 +72,7 @@ use Data::Dumper;
 
 =head1 NAME
 
-File::Unpack - An aggressive archive file unpacker, based on mime-types
+File::Unpack - An aggressive bz2/gz/zip/tar/cpio/rpm/deb/cab/lzma/7z/rar/... archive unpacker, based on mime-types
 
 =head1 VERSION
 
@@ -80,7 +80,7 @@ Version 0.27
 
 =cut
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 $ENV{PATH} = '/usr/bin:/bin';
 $ENV{SHELL} = '/bin/sh';
@@ -709,7 +709,7 @@ sub unpack
 	  push @{$self->{error}}, "unpack dir ($archive) failed: $!";
 	}
     }
-  else
+  elsif (-f $archive)
     {
       if ($self->_not_excluded($subdir, $in_file) and
           !defined($self->{done}{$archive}))
@@ -839,6 +839,10 @@ sub unpack
 	    }
 	}
     }
+  else
+    {
+      $self->logf($archive => { "skipped" => "special file"});
+    }
 
   if (--$self->{recursion_level} == 0)
     {
